==> komparator_0.3.orig.tar.bz2: komparator4-0.3/src/komparator.h <==
/***************************************************************************
 *   Copyright (C) 2005-2010 by Georg Hennig                               *
 *   Email: georg.hennig@web.de                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifndef _KOMPARATOR_H_
#define _KOMPARATOR_H_

#include <KMainWindow>

class KUrl;
class KomparatorWidget;

class Komparator : public KMainWindow
{
	Q_OBJECT
	public:
		Komparator( const KUrl &url1, const KUrl &url2 );
		virtual ~Komparator();

	public slots:
		virtual void slotQuit();

	protected:
		bool queryClose();

	private:
		KomparatorWidget *m_komparator_widget;
		bool really_close;
};

#endif // _KOMPARATOR_H_

==> komparator_0.6.orig.tar.bz2: komparator4-0.6/src/komparator.h <==
/***************************************************************************
 *   Copyright (C) 2005-2010 by Georg Hennig                               *
 *   Email: georg.hennig@web.de                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifndef _KOMPARATOR_H_
#define _KOMPARATOR_H_

#include <KMainWindow>

class KUrl;
class KomparatorWidget;

class Komparator : public KMainWindow
{
	Q_OBJECT
	public:
		Komparator( bool start_minimized, const KUrl &url1, const KUrl &url2 );
		virtual ~Komparator();

	public slots:
		virtual void slotQuit();

	protected:
		bool queryClose();

	private:
		KomparatorWidget *m_komparator_widget;
		bool really_close;
};

#endif // _KOMPARATOR_H_
